import logging
import os

import yaml
from pyformance import MetricsRegistry
from yaml import YAMLError
import requests

from pscr_common.metrics import get_reporter
from pscr_common.metadata import MetadataProvider

_logger = logging.getLogger(__name__)


def read_config(config):
    try:
        config_data = yaml.safe_load(config)
        return config_data
    except YAMLError as yex:
        _logger.error("Failed to parse {file}")
        raise yex


def check_response_status(response):
    try:
        response.raise_for_status()
    except requests.exceptions.HTTPError as err:
        if response.status_code != 404:
            metrics_registry = MetricsRegistry()
            env = os.environ.get("ENV_ID", "unknown")
            env_meta = MetadataProvider().get_metadata()
            metrics_reporter = get_reporter(
                metrics_registry,
                env,
                env_meta.task_id,
                "dre_c_rule_publisher",
                env_meta.image.split(":")[-1],
                os.getpid(),
            )
            metrics_registry.counter(f"dre_c_rule_publisher.error.{err}")
            if metrics_reporter is not None:
                metrics_reporter.report_now()
            _logger.error(f"Exception Occurred {err}")
            raise err


# def get_dre_rule_config(environments, e_type, e_name, var):
#     for env_type in environments:
#         if env_type["type"]["name"] == e_type:
#             for env in env_type["type"]["env"]:
#                 if env["name"] == e_name:
#                     return env[var]
#
#     _logger.warning(f"No Configuration Found for env {e_name} returning default rule config")


def get_env_config(environments, e_type):
    return {
        d1["name"]: d1
        for d1 in {d["type"]["name"]: d for d in environments}[e_type]["type"]["env"]
    }


def get_dre_rule_config(env_config, e_name, var):
    return env_config[e_name][var]


def get_depl_manifest(config_data_obj):
    config = os.path.join(
        os.path.dirname(__file__), "../config/deployment-manifest.yml"
    )
    config_data = read_config_file(config)
    return config_data[config_data_obj]


def read_config_file(file):
    try:
        with open(file, "r") as fh:
            config_data = yaml.safe_load(fh)
            return config_data
    except YAMLError as yex:
        raise yex
    except FileNotFoundError as fex:
        raise fex
    except Exception as ex:
        raise ex
